package edu.ntnu.stud.chaosgame.model.handling;

import edu.ntnu.stud.chaosgame.game.ChaosGameDescription;
import edu.ntnu.stud.chaosgame.model.Vector2D;
import java.util.Random;

/**
 * Class representing the chaos game.
 */
public class ChaosGame {

  /**
   * The canvas for this ChaosGame
   */
  private ChaosCanvas canvas;

  /**
   * The chaos game description.
   */
  private ChaosGameDescription description;

  /**
   * The description for this ChaosGame
   */
  // private ChaosGameDescription description;

  /**
   * The current point in the chaos game.
   */
  private Vector2D currentPoint;

  /**
   * The random number generator for the chaos game.
   */
  private Random random;

  /**
   * Number of transforms
   */
  private int numOfTransforms;

  public ChaosGame(ChaosGameDescription description, ChaosCanvas canvas) {
    this.canvas = canvas;
    this.description = description;
    this.random = new Random();
    this.numOfTransforms = description.getTransforms().size();
    this.currentPoint = new Vector2D(0, 0);
  }

  /**
   * Get the canvas of this chaos game.
   * @return the canvas.
   */
  public ChaosCanvas getCanvas() { return this.canvas; }

  /**
   * Run the chaos game for n iterations.
   *
   * @param n the number of iterations
   */
  public void runSteps(int n) {
    for (int i = 0; i < n; i++) {
      int j = this.random.nextInt(0, this.numOfTransforms);
      this.currentPoint = this.description.getTransforms().get(j).transform(currentPoint);
      System.out.println(currentPoint.getX0() + " " + currentPoint.getX1());
      this.canvas.putPixel(currentPoint);
    }
    this.canvas.printCanvas();
  }

}
